@@ -669,7 +669,7 @@ class Install(MethodsInterface):
         """
         Скопировать прочие настройки из текущей системы в новую
         """
-        file_mask = re.compile("(/etc/ssh/ssh_host_.*|"
+        file_mask = re.compile("(/etc/ssh/ssh_host_.*|/etc/machine-id|"
                                "/root/.ssh/(id_.*|known_hosts))(?!\.old)")
         target_dir = target.getDirectory()
         source_dir = source.getDirectory()
@@ -778,6 +778,7 @@ class Install(MethodsInterface):
             install_admin.save()
         return True
 
+
     def init_themes(self):
         self.clVars.Get('cl_splash_image_hash')
         self.clVars.Get('cl_grub_image_hash')
